<?php
/*
Copyright 2014 Aaron Gong Hsien-Joen <aaronjxz@gmail.com>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

require_once('base.ais.php');

// char* - AIS \r terminated string
function process_ais_raw($rawdata) { // return int
    static $num_seq; // 1 to 9
    static $seq; // 1 to 9
    static $pseq; // previous seq

    static $msg_sid = -1; // 0 to 9, indicate -1 at start state of device, do not process messages
    static $cmsg_sid; // current msg_sid
    static $itu; // buffer for ITU message

    $filler = 0; // fill bits (int)
    $chksum = 0;

    // raw data without the \n

    // calculate checksum after ! till *
    // assume 1st ! is valid
    
    // find * ensure that it is at correct position
    $end = strrpos ( $rawdata , '*' );
    if ($end === FALSE) return -1; // check for NULLS!!!
    
    $cs = substr( $rawdata, $end + 1 );
    if ( strlen($cs) != 2 ) return -1; // correct cs length
    $dcs = (int)hexdec( $cs );
    
    for ( $alias=1; $alias<$end; $alias++) $chksum ^= ord( $rawdata[$alias] ); // perform XOR for NMEA checksum

    if ( $chksum == $dcs ) // NMEA checksum pass
    {
        $pcs = explode(',', $rawdata.',');
        // !AI??? identifier
        $num_seq = (int)$pcs[1]; // number of sequences
        $seq = (int)$pcs[2]; // get sequence

        // get msg sequence id
        if ($pcs[3] == '') // non-multipart message, set to -1
        {
            $msg_sid = -1;
        }
        else // multipart message
        {
            $msg_sid = (int)$pcs[3];
        }
        $ais_ch = $pcs[4]; // get AIS channel

        // message sequence checking
        if ($num_seq < 1 || $num_seq > 9)
        {
            //echo "ERROR,INVALID_NUMBER_OF_SEQUENCES ".time()." $rawdata\n";
            return -1;
        }
        else if ($seq < 1 || $seq > 9)
        { // invalid sequences number
            //echo "ERROR,INVALID_SEQUENCES_NUMBER ".time()." $rawdata\n";
            return -1;
        }
        else if ($seq > $num_seq)
        {
            //echo "ERROR,INVALID_SEQUENCE_NUMBER_OR_INVALID_NUMBER_OF_SEQUENCES ".time()." $rawdata\n";
            return -1;
        }
        else
        { // sequencing ok, handle single/multi-part messaging
            if ($seq == 1) // always init to 0 at first sequence
            {
                $filler = 0; // ?
                $itu = ""; // init message length
                $pseq = 0; // note previous sequence number
                $cmsg_sid = $msg_sid; // note msg_sid
            }
            if ($num_seq > 1) // for multipart messages
            {
                if ($cmsg_sid != $msg_sid // different msg_sid
                    || $msg_sid == -1 // invalid initial msg_sid
                    || ($seq - $pseq) != 1 // not insequence
                    )
                {  // invalid for multipart message
                    $msg_sid = -1;
                    $cmsg_sid = -1;
                    //echo "ERROR,INVALID_MULTIPART_MESSAGE ".time()." $rawdata\n";
                    return -1;
                }
                else 
                {
                    $pseq++;
                }
            }

            $itu = $itu.$pcs[5]; // get itu message
            $filler += (int)$pcs[6][0]; // get filler

            if ($num_seq == 1 // valid single message
                || $num_seq == $pseq // valid multi-part message
                )
            {
                if ($num_seq != 1) // test
                {
                    //echo $rawdata;
                }
                return process_ais_itu($itu, strlen($itu), $filler /*, $ais_ch*/);
            }
        } // end process raw AIS string (checksum passed)
    }
    return -1;
}


function process_ais_itu($_itu, $_len, $_filler /*, $ais_ch*/) {
    GLOBAL $port; // tcpip port...
    static $debug_counter = 0;
    //DEBUG echo $_itu."\n";
    $x_a = array();
    for ($i = 0; $i<$_len; $i++) $x_a[] = ord($_itu[$i]); // convert string to array bytes

    //$debug_counter=$debug_counter+1;
    //echo ">>>> $debug_counter\n";
    $id = (int)ais2int($x_a, 6, 0); // msg id
    //echo $id."\n";
    $mmsi = 0;
    $name = '';
    $sog = -1.0;
    $cog = 0.0;
    $lon = 0.0;
    $lat = 0.0;
    $cls = 0; // class undefined
    if ($id >= 1 && $id <= 3) {
        $mmsi = ais2int($x_a, 30, 8); // mmsi
        $lon = make_lonf( ais2int($x_a, 28, 61) ); // lon
        $lat = make_latf( ais2int($x_a, 27, 89) ); // lat
        $sog = (float)ais2int($x_a, 10, 50) / 10.0; // sog
        $cog = (float)ais2int($x_a, 12, 116) / 10.0; // cog
        //$hdg = ais2int($x_a, 9, 128); // hdg
        $cls = 1; // class A
    }
    else if ($id == 18) {
        $mmsi = ais2int($x_a, 30, 8); // mmsi
        $lon = make_lonf( ais2int($x_a, 28, 57) ); // lon
        $lat = make_latf( ais2int($x_a, 27, 85) ); // lat
        $sog = (float)ais2int($x_a, 10, 46) / 10.0; // sog
        $cog = (float)ais2int($x_a, 12, 112) / 10.0; // cog
        //$hdg = ais2int($x_a, 9, 124); // hdg
        $cls = 2; // class B
    }
    else if ($id == 19) {
        $mmsi = ais2int($x_a, 30, 8); // mmsi
        $lon = make_lonf( ais2int($x_a, 28, 61) ); // lon
        $lat = make_latf( ais2int($x_a, 27, 89) ); // lat
        $sog = (float)ais2int($x_a, 10, 46) / 10.0; // sog
        $cog = (float)ais2int($x_a, 12, 112) / 10.0; // cog
        //$hdg = ais2int($x_a, 9, 124); // hdg
        $name = ais2char($x_a, 20, 143); // name
        $name = str_replace ( '@' , '', $name ); // sanitize name...
        $cls = 2; // class B
    }
    else if ($id == 5) {
        $mmsi = ais2int($x_a, 30, 8); // mmsi
        //echo ais2int($x_a, 30, 40)."\n"; // IMO Number
        //echo ais2char($x_a, 7, 70)."\n"; // callsign
        $name = ais2char($x_a, 20, 112); // name
        $name = str_replace ( '@' , '', $name ); // sanitize name...
        $cls = 1; // class A
    }
    else if ($id == 24) {
        $mmsi = ais2int($x_a, 30, 8); // mmsi
        $pn = ais2int($x_a, 2, 38); // mmsi
        if ($pn == 0)
        {
            $name = ais2char($x_a, 20, 40); // name
            $name = str_replace ( '@' , '', $name ); // sanitize name...
        }
        $cls = 2; // class B
    }
    if ($mmsi > 0 && $mmsi<1000000000) {// valid mmsi only...
        $utc = time();
        //$utc=$letzteZeit;
        //echo "$mmsi, $name, $utc, $lon, $lat, $sog, $cog, $cls, $port<br>\n";
        $id="$mmsi, $name, $utc, $lon, $lat, $sog, $cog, $cls, $port<br>\n";
    }
    return $id;
}

function process_ais_buf($ibuf) // from serial or IP comms
{
    static $cbuf = "";
    
    $cbuf = $cbuf.$ibuf;

    $last_pos = 0;
    while ( ($start = strpos($cbuf,"VDM",$last_pos)) !== FALSE)
    //while ( ($start = strpos($cbuf,"!AI",$last_pos)) !== FALSE)
    {
        //DEBUG echo $cbuf;
        if ( ($end = strpos($cbuf,"\r\n", $start)) !== FALSE) //TBD need to trim?
        {
            $tst = substr($cbuf, $start - 3, ($end - $start + 3));
            //DEBUG echo "[$start $end $tst]\n";
            $result=process_ais_raw( $tst );
            $last_pos = $end + 1;
        }
        else
        {
            break;
        }
    }
    
    if ($last_pos > 0) $cbuf = substr($cbuf, $last_pos); // move...
    if (strlen($cbuf) > 1024) $cbuf = ""; // prevent overflow simple mode...
    return $result;
}

function imageText($string,$dir){
//Bild erzeugen

  if (!is_file($dir."/".$string.'.png')){

    if (!is_dir($dir)){
      mkdir($dir);
    }

    $imgwidth=strlen($string)*6;
    $imgheight=16;
    $fontsize=2;
     
    $img = imagecreate($imgwidth, $imgheight); 
    //??? 
    $color['lime'] = imagecolorallocate($img, 0x00, 0xFF, 0x00); 
    //Schwarze Farbe setzen 
    $color['black'] = imagecolorallocate($img, 0x00, 0x00, 0x00); 
    //Text schreiben 
    imagestring($img,$fontsize,1,1,$string, $color['black']); 
    //Hintergrundfarbe entfernen (transparent) 
    imagecolortransparent($img, $color['lime']); 
    //PNG-Datei erzeugen  
    imagepng($img,$dir."/".$string.'.png');
  }
}

// Test With Large Array (file)

$ausgabe="";

// Zuerst lesen wir die Liste der bekannten Schiffsnamen ein
if (is_file("boats.csv")){
  // Wir lesen die Liste der bekannten Schiffsnamen ein und stellen
  // diese für aktuelle Sichtungen und Neuerfassungen bereit
  $ships = fopen("boats.csv", "r");
  $zeilen = array();
  while (!feof($ships)) {
     $zeilen[] = fgets($ships);
  }
  fclose($ships);
  
  foreach ($zeilen as $gesamtzeile) {
    list($id,$name)=explode("|",$gesamtzeile."|");
    $shiplist[$id]['name']=trim($name);
    $shiplist[$id]['id']=trim($id);
    //echo $shiplist[$id]['id'].' '.$shiplist[$id]['name']."\n";    
  }
}

// Wir lesen die aktuell empfangenen NMEA-AIS-Datensätze aus der Datei
// nmea-sample ein
$nmea = fopen("nmea-sample", "r");
$zeilen = array();
while (!feof($nmea)) {
   $zeilen[] = fgets($nmea);
}
fclose($nmea);


foreach ($zeilen as $gesamtzeile) {
    list($time,$zeile)=explode("!",$gesamtzeile."!");
   
    // Wer sich nicht innerhalb von 3 Stunden gemeldet hat, ist nicht da.  
    if ($time < (time()-10800)){
        continue;
    }
    $zeile='!'.$zeile;

    $result=process_ais_buf($zeile);
    if ($result<>-1){
        list($ID,$name,$timeX,$lon,$lat,$speed,$kurs,$x)=explode(",",$result.",,,,,,,");
	$satzTMP=$ID.",".$name.",".$time.",".$lon.",".$lat.",".$speed.",".$kurs.",".$x;
	// Wenn das Schiff still liegt, gilt die Position 3 Stunden
        if(($time > (time()-10800))&&($speed==0)){
		//$csv[]=$ID.",".$name.",".$time.",".$lon.",".$lat.",".$speed.",".$kurs.",".$x;
		$csv[]=$satzTMP;
	}else{
		// Macht das Schiff Fahrt, gilt die Position 5 Minuten
		if($time > (time()-300)){
			$csv[]=$satzTMP;
		}
	}
	
    }
}

if (!$csv){
    return;
}

sort($csv);

foreach($csv as $zeile){
    $teile = explode(",", $zeile.",");

    if (!isset($teile[4])){
        continue; 
    }
    
    $id=trim($teile[0]);
    
    // Wir versuchen, den Schiffsnamen aus dem AIS oder aus der Liste
    // der gemerkten Schiffsnamen (shiplist) die oben eingelesen wurde,
    // zu ermitteln
    $ship[$id]['name']=trim($teile[1]);

    if(strlen($ship[$id]['name'])<2){
        $ship[$id]['name']="unbekannt";
    }

    // Zeichen wie / ersetzen, da sie im Dateisystem nicht dargestellt werden
    // koennen
    $ship[$id]['name']=str_replace("/","-",$ship[$id]['name']);
    $ship[$id]['name']=str_replace(":","-",$ship[$id]['name']);
    $ship[$id]['name']=str_replace("\\","-",$ship[$id]['name']);
    $ship[$id]['name']=str_replace("_"," ",$ship[$id]['name']);
 
    // Wenn Schiffsname unbekannt und Schiffsname gemerkte Liste bekannt
    // nehmen wir den Schiffsanemn aus der alten Liste
    if((isset($shiplist[$id]['name']))&&($ship[$id]['name'])=="unbekannt"){
      $ship[$id]['name']=$shiplist[$id]['name'].' (M)';
    }

    // Wenn Schiffsname mit aktuellem AIS-Datensatz empfangen,
    // nehmen wir den Namen aus dem AIS-Datensatz, und merkend den auch gleich
    if(strlen($teile[1])>1){

        $ship[$id]['name']=trim($teile[1]);
        
        // Um doppelungen zu vermeiden schreiben wir immer die
        // komplette Datei neu, löschen also zuerst die alte
        if(is_file('boats.csv')){
            unlink('boats.csv');
        }
        // Wir wollen nicht nur das aktuelle Schiff, sondern alle bekannten
        // aus $shiplist speichern:
        $shiplist[$id]['name']=trim($teile[1]);
        $shiplist[$id]['id']=trim($teile[0]);
        foreach ($shiplist as $znr => $schiff){
          if (($schiff['id'])and($schiff['name']<>'unbekannt')){
            file_put_contents('boats.csv',$schiff['id'].'|'.$schiff['name'].'|'."\n",FILE_APPEND);
          }
        }

        continue;
    }

    $ship[$id]['id']=trim($teile['0']);
    $ship[$id]['time']=trim($teile['2']);
    $ship[$id]['lon']=trim($teile['3']);
    $ship[$id]['lat']=trim($teile['4']);
    $ship[$id]['speed']=trim($teile['5']);
    $ship[$id]['heading']=trim($teile['6']);
    $ship[$id]['rate2turn']=trim($teile['7']);
    //$ship[$id]['navstatus']=trim($teile['8']);

}

if ($ship){
  foreach($ship as $id => $inhalt){
      $suche="<span style=\"font-size:12px;color:blue;\" onclick=\"exlink_edit('http://www.marinetraffic.com/en/ais/index/search/all?keyword=".$inhalt['id']."');\">".$inhalt['id']."</span>";
      if ($inhalt['name']<>"unbekannt"){
          $suchname=str_replace(' (M)','',$inhalt['name']);
          $suche2="<span style=\"font-size:12px;color:blue;\" onclick=\"exlink_edit('http://www.marinetraffic.com/en/ais/index/search/all?keyword=".$suchname."');\">".$inhalt['name']."</span>";
      }else{
          $suche2=$inhalt['name'];
      }
      
      
      $MINUTEN=round((time()-$ship[$id]['time'])/60);
      
      // Wir fügend das Schiffsicon ein
      $satz = "$inhalt[lat]\t$inhalt[lon]\t$suche2<br><br>Lat: $inhalt[lat]<br>Lon: $inhalt[lon]<br>\tSOG: $inhalt[speed] kts<br>COG: ".trim(round($inhalt['heading']))." °<br><br>ID: $suche<br><br>Time: ".$MINUTEN." min (".date("H:i").")\t32,32\t-16,-16\tais/icons/".trim(round($inhalt['heading'])).".png\n";
      if ($inhalt['lat']){
        $ausgabe.=$satz;
      }
      
      if(trim($inhalt['name'])<>"unbekannt"){
      // Wir fügen den Namen des Schiffes als Bild neben dem Schiffsicon ein
          imageText($inhalt['name'],"imgNames");
          list($widthName, $heightName, $typeName, $attrName) = getimagesize("imgNames/".$inhalt['name'].".png");
          $satz = "$inhalt[lat]\t$inhalt[lon]\t$suche2<br><br>Lat: $inhalt[lat]<br>Lon: $inhalt[lon]<br>\tSOG: $inhalt[speed] kts<br>COG: ".trim(round($inhalt['heading']))." °<br><br>ID: $suche<br><br>Time: ".$MINUTEN." min (".date("H:i").")\t".$widthName.",".$heightName."\t+10,-10\tais/imgNames/".$inhalt['name'].".png\n";
          if ($inhalt['lat']){
            $ausgabe.=$satz;
          }
      }
      if(trim($inhalt['speed'])*1>0){
      // Wir fügen die Geschwindigkeit des Schiffes als Bild neben dem Schiffsicon
      // unter dem Namen ein
          imageText($inhalt['speed'].' kts',"imgSpeed");
          list($widthName, $heightName, $typeName, $attrName) = getimagesize("imgSpeed/".$inhalt['speed']." kts.png");
          $satz = "$inhalt[lat]\t$inhalt[lon]\t$suche2<br><br>Lat: $inhalt[lat]<br>Lon: $inhalt[lon]<br>\tSOG: $inhalt[speed] kts<br>COG: ".trim(round($inhalt['heading']))." °<br><br>ID: $suche<br><br>Time: ".$MINUTEN." min (".date("H:i").")\t".$widthName.",".$heightName."\t+10,0\tais/imgSpeed/".$inhalt['speed']." kts.png\n";
          if ($inhalt['lat']){
            $ausgabe.=$satz;
          }
      }
  }
}

// Wir schreiben den Kopf der Ausgabedaten
echo "lat\tlon\ttitle\tdescription\ticonSize\ticonOffset\ticon\n";
echo $ausgabe;
?>

