<?PHP

// -----------------------------------------------------------------------------
// Programm zum offline Arbeiten (Erstellen / Bearbeiten)
// -----------------------------------------------------------------------------
//
// Offline werden folgende GPX-Elemente verwendet
// Die ersten 5 Kindobjekte sind von einer original GPX-Datei entnommen
// Kindobjekte beginnend mit einem "ft" sind speziell von der FreienTonne hinzugefügt
// o wpt (mit lat & lon parameter)
//   - ele
//   - name
//   - cmt
//   - desc
//   - sym

//   - ftanzeigenhoehe     # Information für Anzeigenhöhe
//   - ftid                # Durchnummerierung der offline POIs
//   - ftdatum             # Datum wann der POI erstellt wurde
//
// -----------------------------------------------------------------------------
// Konfiguration
// -----------------------------------------------------------------------------
//
// Bildtext
// Für bestimmte Icons soll der Name als Bild in der Karte eingeblendet werden.
// Die Icons werden hier definiert (IDs):
   $bildtext_iconids = array(115);
// Tiefenbilder
// Für welche Position mit den hier genannten Icon-IDs Textbilder für die Tiefenangabe des Namens erstellt werden
// Achtung STRING to FLOAT conversion nach PHP regeln
   $tiefenbilder = array(116);
//
// -----------------------------------------------------------------------------

error_reporting(E_ALL);
$htm = $init = '';
$schreibtest = 'schreibtest.txt';
$makeIcons = FALSE;
$selfpois = 'ft-selfpois-offline.gpx';

// -----------------------------------------------------------------------------
// Prüfen ob Schreibrechte vorhanden
// -----------------------------------------------------------------------------

   $write = FALSE;
   $testhandle = @fopen($schreibtest,"a+");
   if($testhandle) {
      $write = TRUE;
      $makeIcons = TRUE;
      fclose($testhandle);
      unlink($schreibtest);
   } else {
      $htm .= '<b style="color:red;">Offline arbeiten fehlgeschlagen</b><br /><br />
      Leider ist es dem Programm nicht möglich offline zu arbeiten
      (Positionen zu ändern oder zu erstellen), da es keine Zugriffsrechte
      besitzt (Schreib- und/oder Leserechte).<br /><br />
      Wenn Sie nicht eine CD-/DVD-Version nutzen, bzw. einen geschützten
      USB-Stick, prüfen Sie die Rechte in Ihrem OSM-Verzeichnis. Benötigt wird
      vor allem die Datei "ft-selfpois-offline.gpx".
      ';
   }
// -----------------------------------------------------------------------------

// -----------------------------------------------------------------------------
// Funktionen
// -----------------------------------------------------------------------------
//
// Berechnet aus Dezimal-Koordinaten die Grad.Koordinaten (Ausgabe array )
   function dez2grad($dez) {
      if(is_numeric($dez)) {
         $dez = abs($dez);

         $grad  = (int) $dez;
         $temp1 = ($dez - $grad) * 60;
         $min   = (int) $temp1;
         $temp2 = ($temp1 - $min) * 60;
         $sek   = round( $temp2 ,2);

         if($sek >= 60) { $min++; $sek = 0; }
         if($min >= 60) { $grad++; $min = 0; }

         $out = array($grad,$min,$sek);
      } else {
         $out = array('','','');
      }
      return $out;
   }
   function post2clean($parr) {
      foreach($parr as $key => $postdat) {
         if(is_array($postdat)) { $new[$key] = post2clean($postdat); }
         else {
            $postdat = trim($postdat);
            if(get_magic_quotes_gpc()) {
            $postdat = stripslashes($postdat); }
            $new[$key] = $postdat;
         }
      }
      return $new;
   }

   // Text zu einem Bild umwandeln
   function makeTextpic($wort,$size,$ttf,$datei) {
      $bounds = imagettfbbox($size,0,$ttf, $wort);
      $width  = abs($bounds[0]) + abs($bounds[2]);
      $height = abs($bounds[1]) + abs($bounds[7]);

      $img  = imagecreatetruecolor($width,$height);
      $pos  = 0 + abs($bounds[0]);
      $posy = 0 + abs($bounds[7]);
      $color = ImageColorAllocate($img,0,0,0);
      $trans = ImageColorAllocate($img,255,255,255);
      imagefill($img,0,0,$trans);
      imagecolortransparent($img,$trans);


      ImageTTFText($img, $size, 0, $pos, $posy, $color, $ttf, $wort);

      imagepng($img,$datei,9);
      imagedestroy($img);
   }

   // Tiefenangabe zu einem Bild umwandeln
   function makeTiefenpic($wort,$size,$size2,$ttf,$datei) {

      // Prüfen ob Zahl
      $wort = str_replace(',','.',$wort);
      $wort = $wort * 1;
      $tiefe = explode('.',$wort);
      if(!$tiefe) { return FALSE; }

      // Ermitteln der benötigten Größe(n)
      $bounds  = imagettfbbox($size,0,$ttf, $tiefe[0]);
      $width   = abs($bounds[0]) + abs($bounds[2]);
      $height  = abs($bounds[1]) + abs($bounds[7]);
      $pos     = 0 + abs($bounds[0]);
      $posy    = 0 + abs($bounds[7]);

      // Nachkomma ermittlung
      if(!isset($tiefe[1])) { $tiefe[1] = '0'; }
      $tiefe[1]    = $tiefe[1]{0};
      $bounds2     = imagettfbbox($size2,0,$ttf, $tiefe[1]);
      $width2      = abs($bounds2[0]) + abs($bounds2[2]);
      $height2     = abs($bounds2[1]) + abs($bounds2[7]);
      $pos2        = $width;
      $posy2       = $height + ceil( ($height2 / 3) );

      // Bildgesamtgröße
      $bild_width  = $width + $width2;
      $bild_height = $height + ceil( ($height2 / 2) );

      // Erzeugen des Bildes
      $img  = imagecreatetruecolor($bild_width,$bild_height);
      $color = ImageColorAllocate($img,0,0,0);
      $trans = ImageColorAllocate($img,255,255,255);
      imagefill($img,0,0,$trans);
      imagecolortransparent($img,$trans);

      // Schreiben des Metertextes
      ImageTTFText($img, $size, 0, $pos, $posy, $color, $ttf, $tiefe[0]);
      // Schreiben der Nachkommastelle
      if(isset($tiefe[1])) {
         ImageTTFText($img, $size2, 0, $pos2, $posy2, $color, $ttf, $tiefe[1]);
      }

      // Bildausgabe
      imagepng($img,$datei,9);
      imagedestroy($img);

      return TRUE;
   }

// -----------------------------------------------------------------------------




// -----------------------------------------------------------------------------
// Erstellen der Icon-Auswahl (aus Datei)
// -----------------------------------------------------------------------------
if($makeIcons) {
   // Holen den Kategorien
   $icons = array();
   $kategorien_file = file('ft_osm_kategorien.csv');
   foreach($kategorien_file as $line => $kats) {
      if($line != 0) {
         $katdat  = explode("\t",$kats);
         $icons[$katdat[0]] = array();
         $kategorien[$katdat[0]] = $katdat[1];
      }
   }

   // Holen der Icons, und einsortieren
   $icon_file = file('ft_osm_icons.csv');
   $icon_ids  = array();
   foreach($icon_file as $line => $icodats) {
      if($line != 0) {
         $icodats = trim($icodats);
         $icodat = explode("\t",$icodats);
         $icons[$icodat[3]][$icodat[0]] = array(
            'name' => $icodat[1],
            'gps' => $icodat[2],
            'anzeigenhoehe' => $icodat[4],
            'show_name' => $icodat[5],
            'show_beschreibung' => $icodat[6]
         );
         $icon_ids[] = $icodat[0];
      }
   }

   // Erstellen der HTML-Ausgabe
   $value['iconauswahl'] = '';
   foreach($icons as $katid => $iconsarray) {
      $value['iconauswahl'] .= '<br />'.$kategorien[$katid].'<br />';
      foreach($iconsarray as $iconid => $icondat) {
         $bildrahmen = 'border:0px solid #000';
         if($iconid == 115 OR $iconid == 81 OR $iconid == 116) {
            $bildrahmen = 'border:1px dotted #000;';
         }
         $value['iconauswahl'] .= '
         <img src="icons/'.$iconid.'.png" width="16" height="16" style="'.$bildrahmen.'"
              alt="'.$icondat['name'].'" title="'.$icondat['name'].'"
              onclick="put(\'iconid\',\''.$iconid.'\',\''.$icondat['gps'].'\',\''.htmlspecialchars($icondat['name']).'\',
                       \''.$icondat['anzeigenhoehe'].'\',\''.$icondat['show_name'].'\',\''.$icondat['show_beschreibung'].'\');" />
         ';
      }
   }

   // $htm = '<pre>'.print_r($icons,1).'</pre>';

}

$gpx1 = '<?xml version="1.0" encoding="UTF-8"?>
<gpx
   version="1.0"
   creator="FreieTonne - http://www.freietonne.de"
   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
   xmlns="http://www.topografix.com/GPX/1/0"
   xsi:schemaLocation="http://www.topografix.com/GPX/1/0 http://www.topografix.com/GPX/1/0/gpx.xsd">
   <time>'.date("Y-m-d").'T'.date("H:i:s").'Z</time>
   <bounds minlat="52.341177575" minlon="13.636163045" maxlat="52.373702964" maxlon="13.703133445"/>
';
$gpx2 = '</gpx>';








if(isset($_POST['abbrechen']) OR isset($_GET['abbrechen'])) {

   // Javascript Funktion "closeKillIcon" ist in diesem Script
   // ganz unten im XHTML Bereich definiert
   $init = ' onload="closeKillIcon();"';

// -----------------------------------------------------------------------------
// Löschen einer Position
// -----------------------------------------------------------------------------
} elseif(isset($_GET['delgps']) AND $write) {

   $htm .= '<b>Eigene Position löschen</b><br /><br />';

   // Holen der POI-Information
   // Auslesen der Datei ft-selfpois-offline.gpx
   $gpx = file_get_contents('ft-selfpois-offline.gpx');
   $xml = new SimpleXMLElement($gpx);

   // Erstellen von vorhandenen POIs
   foreach($xml->wpt AS $pos) {
      if($pos->ftid == $_GET['delgps']) {
         $poi_name = $pos->name;
         break;
      }
   }
   
   if(isset($poi_name)) {
   
      // Position soll gelöscht werden
      if(isset($_GET['delgpscheck'])) {
      
         $gpxpois = '';

         foreach($xml->wpt AS $handle => $pos) {
            if($pos->ftid != $_GET['delgps']) {
               // Check für alte GPX-Dateien ohne Datumfeld
               if(isset($pos->ftdatum)) { $ftdatum = $pos->ftdatum; } else { $ftdatum = date("Y-m-d H:i:s"); }
               $gpxpois .= '
               <wpt lat="'.$pos['lat'].'" lon="'.$pos['lon'].'">
                  <ele>'.$pos->ele.'</ele>
                  <name>'.$pos->name.'</name>
                  <cmt>'.$pos->cmt.'</cmt>
                  <desc>'.$pos->desc.'</desc>
                  <sym>'.$pos->sym.'</sym>

                  <ftanzeigenhoehe>'.$pos->ftanzeigenhoehe.'</ftanzeigenhoehe>
                  <ftid>'.$pos->ftid.'</ftid>
                  <ftdatum>'.$ftdatum.'</ftdatum>
               </wpt>
               ';
            }
         }
         
         // Neu schreiben der GPX-Datei
         $handle = fopen($selfpois,"w+");
         fwrite($handle,$gpx1);
         fwrite($handle,$gpxpois);
         fwrite($handle,$gpx2);
         fclose($handle);
         
         // Löschen von evt. Textbild
         $textbild = 'iconnamenself/'.$_GET['delgps'].'.png';
         if(is_file($textbild)) { unlink($textbild); }

         header("Location: ft-editpois.php?abbrechen=1"); exit;

      // Sicherheitsabfrage ob die Position tatächlich gelöscht werden soll.
      } else {
         $htm .= 'Sind Sie sicher, daß Sie die Position mit dem Namen "'.htmlspecialchars($_GET['delgps']).'" löschen wollen?<br /><br />
         <table cellspacing="0" cellpadding="0" border="0" style="width:100%;"><tr>
         <td>[<a href="ft-editpois.php?abbrechen=1">NEIN</a>]</td>
         <td style="text-align:right;">[<a href="ft-editpois.php?delgps='.$_GET['delgps'].'&delgpscheck=1">JA</a>]</td>
         </tr></table>';
      }
   // Es konnte keine Position mit der ID gefunden werden
   } else {
      $htm .= 'Die angegebene Position konnte nicht in der Offline-Datei gefunden werden.
      Vermutlich wurde diese Position bereits gelöscht.
      <br /><br />
      <a href="ft-editpois.php?abbrechen=1">Fenster schließen</a>';
   }
   

// -----------------------------------------------------------------------------
// Neue Position
// -----------------------------------------------------------------------------
} elseif(isset($_POST['newgps']) AND $write) {

   $htm_zusatzcss = 'div.zusatzerklaerung { display:none;margin-top:10px;margin-bottom:10px; }';
   $_POST = post2clean($_POST);

   // Prüfen ob Position existiert
   // Prüfen ob Zahl

   // Fehlerprüfung
   $check = 0;
   $error['bdez'] = $error['ldez'] = $error['hoehe'] = $error['icon'] = $error['iconid'] = $error['name'] = $error['beschreibung'] = $error['anzeigenhoehe'] = '';

   $htm_coordb = $_POST['bdez'];
   $htm_coordl = $_POST['ldez'];
   $_POST['bdez'] = str_replace(',','.',$_POST['bdez']);
   if(!is_numeric($_POST['bdez']) OR $_POST['bdez'] < -90 OR $_POST['bdez'] > 90) {
      $check++; $error['bdez'] = '<span class="error">&nbsp;<br />Keine gültige Breitenangabe.</span>';
      $htm_coordb = 0; }
   $_POST['ldez'] = str_replace(',','.',$_POST['ldez']);
   if(!is_numeric($_POST['ldez']) OR $_POST['ldez'] < -180 OR $_POST['ldez'] > 180) {
      $check++; $error['ldez'] = '<span class="error">&nbsp;<br />Keine gültige Längenangabe</span>';
      $htm_coordl = 0; }

   // Icon-ID
   $value['iconzoom'] = $_POST['icon'];
   if(!ctype_digit($_POST['icon'])) {
      $check++; $error['icon'] = '<span class="error">&nbsp;<br />Keine gültige Icon-ID</span>';
      $value['iconzoom'] = 81;
   } else {
      if(!in_array($_POST['icon'],$icon_ids)) {
         $check++; $error['icon'] = '<span class="error">&nbsp;<br />Keine gültige Icon-ID</span>';
         $value['iconzoom'] = 81;
      }
   }
   // $htm .= '<p><b>'.$_POST['icon'].'</b></p>';
   // $htm .= '<pre>'.print_r($icon_ids,1).'</pre>';

   // Anzeigenhoehe durchchecken
   $value['anzeigenhoehe'] = array('','','',''); $anzeigenhoehe_array = array(1,2,3);
   if(!in_array($_POST['anzeigenhoehe'],$anzeigenhoehe_array)) {
      $check++; $error['anzeigenhoehe'] = '<span class="error">&nbsp;<br />Es wurde eine ungültige Anzeigenhoehe übermittelt.</span>';
      $value['anzeigenhoehe'] = array('','','','');
   } else {
      $value['anzeigenhoehe'][$_POST['anzeigenhoehe']] = ' selected="selected"';
   }

   //if(strlen($_POST['name']) < 2) { $check++; $error['name'] = '<span class="error">&nbsp;<br />Sie haben keinen Namen eingegeben.</span>'; }



   // Rückgabe des Formulars ---------------------------------------------------
   if($check) {

      // Formulardaten
      $value['bdez']             = $_POST['bdez'];
      $value['ldez']             = $_POST['ldez'];
      $value['hoehe']            = $_POST['hoehe'];
      $value['icon']             = $_POST['icon'];
      $value['name']             = $_POST['name'];
      $value['beschreibung']     = $_POST['beschreibung'];
      $value['zusatzerklaerung'] = '';
      if(isset($_POST['zusatzerklaerung'])) { $value['zusatzerklaerung'] = ' checked="checked"'; }
      $value['showname']         = ''; if(isset($_POST['showname'])) { $value['showname'] = ' checked="checked"';}
      $value['showbeschreibung'] = ''; if(isset($_POST['showbeschreibung'])) { $value['showbeschreibung'] = ' checked="checked"'; }

      $bgrad = dez2grad($_POST['bdez']);
      $value['bgra'] = $bgrad[0];
      $value['bmin'] = $bgrad[1];
      $value['bsek'] = $bgrad[2];
      $value['bvors'] = ''; $value['bvorn'] = ' checked="checked"';
      if($_POST['bdez'] < 0) { $value['bvors'] = ' checked="checked"'; $value['bvorn'] = ''; }

      $lgrad = dez2grad($_POST['ldez']);
      $value['lgra'] = $lgrad[0];
      $value['lmin'] = $lgrad[1];
      $value['lsek'] = $lgrad[2];
      $value['lvorw'] = ''; $value['lvoro'] = ' checked="checked"';
      if($_POST['ldez'] < 0) { $value['lvorw'] = ' checked="checked"'; $value['lvoro'] = ''; }

      $value['submit'] = 'newgps';
      $value['id'] = 0;
      include('ft-editpois-formular.php');
      $htm .= $seitenformular;

   // Eintragen in eigene POIs (ft-selfpois-offline.gpx)
   } else {

      // Prüfen ob eine Datei mit eigenen POIs existiert, ansonsten erstellen
      if(!is_file($selfpois)) {
         $handle = fopen($selfpois,"w+");
         fwrite($handle,$gpx1);
         fwrite($handle,$gpx2);
         fclose($handle);
      }

      // Auslesen der Datei ft-selfpois-offline.gpx
      $gpx = file_get_contents('ft-selfpois-offline.gpx');
      $xml = new SimpleXMLElement($gpx);
      
      // Erstellen von vorhandenen POIs
      $gpxpois = ''; $last_id = 0;
      foreach($xml->wpt AS $pos) {
         // Check für alte GPX-Dateien ohne Datumfeld
         if(isset($pos->ftdatum)) { $ftdatum = $pos->ftdatum; } else { $ftdatum = date("Y-m-d H:i:s"); }
         $gpxpois .= '
         <wpt lat="'.$pos['lat'].'" lon="'.$pos['lon'].'">
            <ele>'.$pos->ele.'</ele>
            <name>'.$pos->name.'</name>
            <cmt>'.$pos->cmt.'</cmt>
            <desc>'.$pos->desc.'</desc>
            <sym>'.$pos->sym.'</sym>

            <ftanzeigenhoehe>'.$pos->ftanzeigenhoehe.'</ftanzeigenhoehe>
            <ftid>'.$pos->ftid.'</ftid>
            <ftdatum>'.$ftdatum.'</ftdatum>
         </wpt>
         ';
         $ftid = $pos->ftid + 0;
         if($ftid > $last_id) { $last_id = $ftid; }
      }
      
      // Ermitteln einer neuen ID aus "ft-selfpois-offline-counter.txt"
      if(is_file('ft-selfpois-offline-counter.txt')) {
         $letzte_id = file_get_contents('ft-selfpois-offline-counter.txt');
         if(ctype_digit($letzte_id)) {
            $neue_id = $letzte_id + 1;
         } else {
            $neue_id = $last_id + 1;
         }
      } else {
         $neue_id = $last_id + 1;
      }
      $handle2 = fopen('ft-selfpois-offline-counter.txt',"w+");
      fwrite($handle2,$neue_id);
      fclose($handle2);

      // Hinzufügen der neuen Position
      // Elemente nach <sym> sind nicht mehr Garmin-konform, sondern
      // von FreieTonne hinzugefügt
      $gpxpois .= '
      <wpt lat="'.$_POST['bdez'].'" lon="'.$_POST['ldez'].'">
         <ele>'.$_POST['hoehe'].'</ele>
         <name>'.$_POST['name'].'</name>
         <cmt>'.$_POST['beschreibung'].'</cmt>
         <desc>'.$_POST['beschreibung'].'</desc>
         <sym>'.$_POST['icon'].'</sym>
         
         <ftanzeigenhoehe>'.$_POST['anzeigenhoehe'].'</ftanzeigenhoehe>
         <ftid>'.$neue_id.'</ftid>
         <ftdatum>'.date("Y-m-d H:i:s").'</ftdatum>
      </wpt>
      '."\r\n";
      
      // Neu schreiben der GPX-Datei
      $handle = fopen($selfpois,"w+");
      fwrite($handle,$gpx1);
      fwrite($handle,$gpxpois);
      fwrite($handle,$gpx2);
      fclose($handle);
      
      // Bildtext erstellen, wenn benötigt (siehe oben Konfiguration)
      $bilddatei = 'iconnamenself/'.$neue_id.'.png';
      $font      = './verdanab.TTF';
      if(in_array($_POST['icon'],$bildtext_iconids)) {
         makeTextpic($_POST['name'],6,$font,$bilddatei);
      } elseif(in_array($_POST['icon'],$tiefenbilder)) {
         makeTiefenpic($_POST['name'],8,6,$font,$bilddatei);
      }

      header("Location: ft-editpois.php?abbrechen=1"); exit;
   }

} elseif(isset($_GET['newgps']) AND $write) {

   // BDEZ : Übergebene Positionsdaten umrechnen und übergeben
   $value['bdez'] = $value['bgra'] = $value['bmin'] = $value['bsek'] = ''; $htm_coordb = 0;
   $value['bvorn'] = ' checked="checked"'; $value['bvors'] = '';
   if(isset($_GET['bdez'])) {
      $value['bdez'] = $htm_coordb = $_GET['bdez'];
      $bgrad = dez2grad($_GET['bdez']);
      $value['bgra'] = $bgrad[0];
      $value['bmin'] = $bgrad[1];
      $value['bsek'] = $bgrad[2];
      if($_GET['bdez'] < 0) { $value['bvorn'] = ''; $value['bvors'] = ' checked="checked"'; }
   }

   // LDEZ : Übergebene Positionsdaten umrechnen und übergeben
   $value['ldez'] = $value['lgra'] = $value['lmin'] = $value['lsek'] = ''; $htm_coordl = 0;
   $value['lvoro'] = ' checked="checked"'; $value['lvorw'] = '';
   if(isset($_GET['ldez'])) {
      $value['ldez'] = $htm_coordl = $_GET['ldez'];
      $lgrad = dez2grad($_GET['ldez']);
      $value['lgra'] = $lgrad[0];
      $value['lmin'] = $lgrad[1];
      $value['lsek'] = $lgrad[2];
      if($_GET['ldez'] < 0) { $value['lvoro'] = ''; $value['lvorw'] = ' checked="checked"'; }
   }


   $value['hoehe'] = '';
   $value['icon'] = '';
   $value['iconzoom'] = 81;
   $value['anzeigenhoehe'] = array('','','','');
   $value['name'] = '';
   $value['beschreibung'] = '';

   $value['showname'] = $value['showbeschreibung'] = '';
   $value['zusatzerklaerung'] = '';
   $value['id'] = 0;
   $value['submit'] = 'newgps';

   $error = array('bdez'=>'','ldez'=>'','hoehe'=>'','icon'=>'','anzeigenhoehe'=>'','name'=>'','beschreibung'=>'','edittxt'=>'');

   // Laden des Formular
   include('ft-editpois-formular.php');
   $htm .= $seitenformular;


} else {  }


// -----------------------------------------------------------------------------
// XHTML-Ausgabe
// -----------------------------------------------------------------------------
//
// Beinhaltet alle benötigten CSS und JS
//
// -----------------------------------------------------------------------------

if(!isset($htm_coordb)) { $htm_coordb = 0; }
if(!isset($htm_coordl)) { $htm_coordl = 0; }

$xhtml = '
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE html
         PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
         "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="de" lang="de">
<head>
   <title>FreieTonne</title>

   <meta http-equiv="content-type" content="application/xhtml+xml;charset=utf-8" />
   <meta name="content-language" content="de" />
   <meta name="title" content="FreieTonne - Kostenloses Seezeichen-Verzeichnis" />
   <meta name="author" content="Jan Jesse, Berlin, Germany" />
   <meta name="description" content="Entwicklung eines freien Verzeichnisses von See- und Schifffahrtszeichen durch freie Mitarbeit eines jeden Skippers, nur mit Hilfe eines Computers und GPS-Gerätes." />

   <meta name="keywords" content="Seefahrtszeichen, Seezeichen, Seekarte, Karte, Gewässerkarte, Schifffahrtszeichen, Schiffahrtszeichen, Tonnen, Tonne, Freie, Freietonne, Leuchttonne, Stumpftonne, Spitztonne, Kugeltonne, Spierentonne, Tonnenverzeichniss, Tonnenindex, Pricke, Leuchtturm, Hauptzeichen, Verbotszeichen, Gebotszeichen, Community, Tonnensammler, kartographieren, Wasserwanderatlas, Navigation, Ostsee, Müritz, Binnenwasserstrassen, Nordsee, Spree, Schleuse, Schleusen, Wehr, Skipper, Törnplanung, Hafen, Hafenlotse, Lotse, GPS, GPS-Geräte, Navigationsgerät, GPS-Gerät, Kartenplotter" />
   <meta name="copyright" content="2008 Jan Jesse" />
   <meta name="page-type" content="Information" />
   <meta name="revisit-after" content="1 days" />
   <meta name="robots" content="follow" />



   <meta name="apple-mobile-web-app-capable" content = "yes" />
   <meta name="apple-mobile-web-app-status-bar-style" content = "black-translucent" />
   <meta name="viewport" content="user-scalable=no, width=550">
   
   <style type="text/css">
      @charset "utf-8";

      html,body,form,table,tr,th,td,select,input,textarea,img {
         margin:0px;
         padding:0px;
      }
      body {
         background-color:#f3ebd9;
         padding: 20px;
         font-family: Verdana, Arial, Helvetica;
         font-size: 11pt;
         vertical-align: top;
      }
      a:link, a:visited, a:hover, a:active {
         text-decoration: none;
         font-weight: bold;
      }
      td {

      }
      #admin form {
         border-width:0px;
         margin:0px;
         padding:0px;
         }
      #admin textarea {
         font-family:verdana,helvetica,sans-serif;
         font-size:12px;
         border-width:1px;
         border-style:solid;
         border-color:#666666;
         }
      #admin .inputtext {
         font-family:verdana,helvetica,sans-serif;
         font-size:12px;
         border-width:1px;
         border-style:solid;
         border-color:#666666;
         }
      #admin .buttonhtml {
         font-family:verdana,helvetica,sans-serif;
         font-size:12px;
         border-width:1px;
         border-style:solid;
         border-color:#666666;
         background-color:#ccc;
         padding:0;
         margin:0;
         }
      #admin td {
         padding-bottom:5px;
         }
      #admin .submit {
         font-family:verdana,helvetica,sans-serif;
         font-size:12px;
         font-weight:bold;
         border-width:1px;
         border-style:solid;
         border-color:#666666;
         background-color:#99cc2b;
         padding:0;
         margin:0;
         }
      #admin .submitred {
         font-family:verdana,helvetica,sans-serif;
         font-size:12px;
         font-weight:bold;
         border-width:1px;
         border-style:solid;
         border-color:#666666;
         background-color:#ff9999;
         padding:0;
         margin:0;
         }
      #admin select {
         font-family:verdana,helvetica,sans-serif;
         font-size:12px;
         color:#666666;
         border-width:1px;
         border-style:solid;
         border-color:#666666;
         padding:0;
         margin:0;
         }
      #admin span.error {
         font-family:verdana,helvetica,sans-serif;
         font-size:9px;
         color:#ff0000;
         font-weight:bold;
      }
      div.zusatzerklaerung { display:none; margin-top:10px; margin-bottom:10px; }
   </style>

   <!-- JAVASCRIPT -->
   <script src="ft.js" type="text/javascript"></script>

   <script type="text/javascript">

      var $coordb="'.$htm_coordb.'"; var $coordl="'.$htm_coordl.'";

      function closeKillIcon () {
         window.location.href="index.php";
         //opener.parent.vorschauicon = false;
         //opener.parent.changePOIs();
         //window.close();
      }

   </script>

</head>

<body'.$init.'>
<div style="font-size:10px; margin-bottom:10px;">
<span style="font-size: 18px;">FreieTonne-Positionen (<span style="color:red;">offline Modus</span>)</span><br />
Im Offline-Modus können Sie nur <b>eigene</b> Positionen erstellen, und löschen.
Das Verändern von Positionen der FreienTonne, ist nur online möglich. (siehe unten für Details)
</div>
'.$htm.'
<div style="font-size:10px; margin-top:20px;border:0px solid #000;border-top-width:1px;">
<b>Hinweise:</b><br />Eigene POIs (Points Of Interest) werden in einer Datei namens
"<a href="ft-selfpois-offline.gpx">ft-selfpois-offline.gpx</a>"
im Format GPX gespeichert. Wenn Sie möchten, können Sie diese Datei online bei der
FreienTonne importieren, Ihre Daten der FreienTonne hinzufügen, und somit allen
Nutzern zur Verfügung stellen.<br /><br />
Zum Löschen aller Ihrer eigenen POIs, löschen Sie einfach die Datei
"ft-selfpois-offline.gpx", oder benennen Sie diese um.
</div>
</body></html>

';
echo $xhtml; exit;
?>
